﻿Fluke                                                       MET/CAL Procedure
=============================================================================
INSTRUMENT:            Tektronix TBS1152B: (1 year) VER VISA /5800A+5Ch
DATE:                  2018-08-10 08:53:06
AUTHOR:                Fluke
REVISION:              $Revision: 25085 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       175
CONFIGURATION:         Fluke 5800A (C5)
=============================================================================
#
#  Procedure Author:
#      PP
#
#  Source(s):
#      TBS1000B and TBS1000B-EDU Series Oscilloscopes
#      Specifications and Performance Verification
#      Technical Reference, PN 077-1025-01, Revision B.*
#      * The tolerances used by this procedure were taken from the published
#      specifications table and is specified below.
#
#  Model(s) Covered:
#      TBS1000B Series
#          TBS1032B, TBS1052B, TBS1072B, TBS1102B, TBS1152B
#		   TBS1202B.
#      TBS1000B-EDU Series
#          TBS1052B-EDU, TBS1072B-EDU, TBS1102B-EDU,
#		   TBS1152B-EDU, TBS1202B-EDU
#
#  Compatibility:
#      MET/CAL 8.0 or later
#
#  Additional Equipment Required:
#      None
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# These statements are here to force the main procedure header to list the
# configuration required by the subprocedures.
  1.001  IF           0
  1.002  M5800                                                    C5
  1.003  5800         4MH                          1Vpp           LS S6 S  L
  1.004  ENDIF

  1.005  ASK-   R   Q N              P                                    V

  1.007  IF           NOT(VERSIONCHECK("8.0"))
  1.008  END
  1.009  ENDIF

  1.010  CALL         Sub Display Copyright
  1.011  CALL         Sub High Voltage Safety Warning
  1.012  CALL         Sub Select Failed Test Mode
  1.013  CALL         Sub Select Verification Method (No NTHROW)

  1.014  HEAD         PRELIMINARY INSTRUCTIONS
  1.015  DISP         Ensure a minimum DUT warm-up time of at least
  1.015  DISP         10 minutes has been allowed to elapse, prior
  1.015  DISP         to beginning verification.

  1.016  HEAD         COMMUNICATION SETUP
  1.017  TARGET
  1.018  CALL         Sub Tek TBS1000B USB Remote Interface Connection
  1.019  VISA         *RST

  1.020  HEAD         DUT IDENTIFICATION
  1.021  CALL         Sub IEEE-488.2 *IDN? VISA
  1.022  MATH         @DUT_Model = "TBS 1152B"
  1.023  MATH         @DUT_Manufacturer = "Tektronix"
  1.024  CALL         Sub IEEE-488.2 *IDN? Check Response
  1.025  JMPL         END                          @Abort

  1.026  CALL         Sub Tek TBS1000B/1000B-EDU Specifications

# Specify whether the calibrator have multi channels during test in order
# to decide proper connection instruction be taken in the sub procedures.
  1.027  MATH         @SourceMultiCh = 1

  1.028  HEAD         EQUIPMENT REQUIREMENTS
  1.029  OPBR         -z Do you want to review the list of additional
  1.029  OPBR         equipment and/or accessories required?

  1.030  IF           MEM1
  1.031  CALL         Sub Tek TBS1000B/1000B-EDU VER Required Equipment /5800
  1.032  ENDIF

# NOTE: The execution order of this verification procedure has been optimized
# to minimize operator intervention, while retaining the correct sequence for
# reported test results.  For more information about the method used, refer
# to this application note, available at www.flukecal.com:
# Application Note 6001075: Optimizing Execution Sequence in MET/CAL Gold
# Procedures While Retaining Results Order.

  1.033  CALL         Sub Tek TBS1000B/1000B-EDU Self-Test VISA
  1.034  JMPL         END                          @Abort
  1.035  CALL         Sub Tek TBS1000B/1000B-EDU Sig Path Comp Cal VISA
  1.036  JMPL         END                          @Abort

  1.037  MATH         @Chan = 1
  1.038  M5800                                                    C1
  1.039  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) DCV Meas VISA /5800

  1.040  MATH         @Chan = 2
  1.041  M5800                                                    C2
  1.042  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) DCV Meas VISA /5800
  1.043  JMPL         VERTICAL_POSITION

  1.044  LABEL        BANDWIDTH
  1.045  MATH         @Chan = 1
  1.046  M5800                                                    C1
  1.047  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Bandwidth VISA /5800

  1.048  MATH         @Chan = 2
  1.049  M5800                                                    C2
  1.050  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Bandwidth VISA /5800

  1.051  MATH         @Chan = 1
  1.052  M5800                                                    C1
  1.053  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Trig Sens VISA /5800

  1.054  MATH         @Chan = 2
  1.055  M5800                                                    C2
  1.056  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Trig Sens VISA /5800
  1.057  JMPL         SAMPLE_RATE_DELAY_TIME

  1.058  LABEL        EXT_TRIG_CH1
  1.059  MATH         @Chan = 1
  1.060  M5800                                                    C1
  1.061  CALL         Sub Tek TBS1000B (1 yr) ExTrig Sens VISA /5800

  1.062  MATH         @Chan = 2
  1.063  M5800                                                    C1
  1.064  CALL         Sub Tek TBS1000B (1 yr) ExTrig Sens VISA /5800
  1.065  JMPL         END

  1.066  LABEL        SAMPLE_RATE_DELAY_TIME
  1.067  MATH         @Chan = 1
  1.068  M5800                                                    C1
  1.069  CALL         Sub Tek TBS1000B (1 yr) Sample Rate VISA /5800
  1.070  JMPL         EXT_TRIG_CH1

  1.071  LABEL        VERTICAL_POSITION
  1.072  MATH         @Chan = 1
  1.073  M5800                                                    C1
  1.074  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Vert Pos VISA /5800

  1.075  MATH         @Chan = 2
  1.076  M5800                                                    C2
  1.077  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Vert Pos VISA /5800
  1.078  JMPL         BANDWIDTH

  1.079  LABEL        END

  1.080  IF           @Abort
  1.081  HEAD         {V E R I F I C A T I O N   A B O R T E D !}
  1.082  ENDIF

  1.083  VISA         *RST
  1.084  END
